@@ -16,7 +16,6 @@ use ra_ap_ide as ra_ide;
 use ra_ap_ide::CompletionFieldsToResolve;
 use ra_ap_ide::FileRange;
 use ra_ap_ide::SubstTyLen;
-use ra_ap_ide_db::EditionedFileId;
 use ra_ap_ide_db::FxHashMap;
 use ra_ap_ide_db::SnippetCap;
 use ra_ap_ide_db::imports::insert_use::ImportGranularity;
@@ -110,7 +109,7 @@ impl RustAnalyzer {
 
     pub(crate) fn set_source(&mut self, source: String) -> Result<()> {
         self.current_source = source;
-        let mut change = ra_hir::ChangeWithProcMacros::new();
+        let mut change = ra_hir::ChangeWithProcMacros::default();
 
         std::fs::write(self.source_file.as_path(), &*self.current_source)
             .with_context(|| format!("Failed to write {:?}", self.source_file))?;
@@ -142,7 +141,11 @@ impl RustAnalyzer {
         use ra_ap_syntax::ast::HasName;
         let mut result = HashMap::new();
         let sema = ra_ide::Semantics::new(self.analysis_host.raw_database());
-        let source_file = sema.parse(EditionedFileId::new(self.source_file_id, EDITION));
+        let source_file = sema.parse(ra_ap_base_db::EditionedFileId::new(
+            sema.db,
+            self.source_file_id,
+            EDITION,
+        ));
         for item in source_file.items() {
             if let ast::Item::Fn(function) = item {
                 if function
@@ -272,17 +275,7 @@ impl RustAnalyzer {
             &FxHashMap::default(),
         );
 
-        let ws_data = FxHashMap::from_iter(crate_graph.iter().map(|crate_id| {
-            (
-                crate_id,
-                triomphe::Arc::new(ra_ap_base_db::CrateWorkspaceData {
-                    data_layout: workspace.target_layout.clone(),
-                    toolchain: workspace.toolchain.clone(),
-                }),
-            )
-        }));
-
-        change.set_crate_graph(crate_graph, ws_data);
+        change.set_crate_graph(crate_graph);
         Ok(())
     }
 
@@ -389,6 +382,7 @@ impl RustAnalyzer {
             max_fields_count: Some(5),
             max_enum_variants_count: Some(5),
             max_subst_ty_len: SubstTyLen::Unlimited,
+            show_drop_glue: false,
         };
         let file_range = FileRange {
             file_id: self.source_file_id,
